#
# spec file for package mpc-qt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mpc-qt
Version:        24.12.1
Release:        4.1
Summary:        Media Player Classic Qute Theater
License:        GPL-2.0-only
URL:            https://github.com/mpc-qt/mpc-qt
Source0:        https://github.com/mpc-qt/mpc-qt/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# For dirs ownership
BuildRequires:  hicolor-icon-theme
BuildRequires:  qt6-tools-linguist
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6DBus)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6OpenGLWidgets)
BuildRequires:  pkgconfig(Qt6Svg)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(mpv) >= 1.101.0

%description
A clone of Media Player Classic reimplemented in Qt.

%prep
%autosetup -p1
rm -rf mpv-dev

%build
qmake6 \
  PREFIX=%{_prefix} MPCQT_VERSION=%{version} \
  mpc-qt.pro
%qmake6_build

%install
%qmake6_install

# Use %%doc instead
rm -r %{buildroot}%{_datadir}/doc/mpc-qt

%files
%doc README.md DOCS/ipc.md
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/applications/io.github.mpc-qt.mpc-qt.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Fri May 23 2025 Christophe Marin <christophe@krop.fr>
- Remove unneeded build dependency
- Spec cleanup
- Don't install translations manually, they're already embedded
  in the executable
* Mon May 12 2025 Luigi Baldoni <aloisio@gmx.com>
- Use current repository in the URL field
* Thu Feb 27 2025 Luigi Baldoni <aloisio@gmx.com>
- Keep original name for the desktop file
* Tue Feb 25 2025 Luigi Baldoni <aloisio@gmx.com>
- Update to version 24.12.1
  Bug fixes:
  * Don't set nowPlayingItem in playNextFileUrl
  * Don't use EGL for Nvidia and log display devices
  * Fix mpv_render_context_render invocation
  * Use reverse DNS + app naming for the .desktop file and
    advertise it
  Other changes:
  * Use Logger::log instead of LogStream wherever possible
  * Send the first log message as early as possible
  * Re-enable aspect ratio when changing it
* Sat Dec  7 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 24.12
  * The position, in addition to audio, video and subtitle
    tracks can now be remembered for 1000 videos.
  * The seek bar is easier to use thanks to a pointing hand
    cursor and a bigger clickable area.
  * Seeking is faster (and playing videos uses less power) on
    Intel integrated GPUs thanks to updated hardware decoding
    backends.
  * You can now easily know which subtitle, audio or video track
    is active. And if you're not a native speaker, disabling the
    "Prefer forced/default subtitles" will make mpc-qt use the
    subtitle track with full close captioning by default.
  * You can adjust the subtitles delay and change (or disable)
    the video aspect ratio.
  * The OSD is now more useful, with the current and total time
    on seek or on key press, the subtitles delay and even the
    aspect ratio name.
  Full changelog at https://github.com/mpc-qt/mpc-qt/compare/v24.06...v24.12
* Tue Jul  2 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 24.06
  Features and/or improvements:
  * Prettify the icon
  * Update some Russian phrases
  * Implement dragging window from the video area
  * Fixed crash on restart when player is closed while minimized
  * Fixed crash when right-clicking playlist window under
    specific circumstances
  * Suppress "errors" from stderr
  * Don't go on top when paused
  * Update list available spdif codecs
  * Restrict web server to localhost by default
  * Add media keys on Windows
  * Implement audio/sub track preference
* Sun Dec 31 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 23.12
  * Port to Qt 6.
  * Fixed some more fractional scaling bugs.
  * Tidied up the unimplemented options in the settings dialog.
  * Implement fullscreen switcher combobox.
  * Implement systray icon.
  * Fix default tracks logic.
  * Fix wayland icon.
  * Add option to use Wayland.
  * Mute button state is preserved across restarts.
- Use g++10 on Leap
- Enable PIE
* Fri Feb 10 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 23.02
  Features and/or improvements in this version:
  * Expose pipewire buffer setting
  * Sanitize more illegal characters from filenames
  * Fix compatibility with newer KDE, dropping some UX fixes for
    older KDE
  * Fix control area hiding on multiple monitors
  * Implement copying subtitle text to clipboard with ctrl-s
  * Turn off prefer forced subs
  * Better support for ultra-dark themes
  * Implement basic ricing support
  In addition, there may be other improvements not listed here.
* Sat Feb  5 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 22.02
  * Add mpc-hc compatible web server
  * Process wheel events over entire window
  * Force use of XCB instead of wayland
  * Possibly other improvements not listed here
- Drop mpc-qt-mpv_v2_fix.patch (merged upstream)
* Sun Jan 30 2022 Luigi Baldoni <aloisio@gmx.com>
- Add mpc-qt-mpv_v2_fix.patch (fix Factory build)
* Fri Oct 16 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 20.10
  Fixes and improvements:
  * Add library window, deleted playlists are now saved instead
    of destroyed
  * Remember shown stats page
  * Implement subtitle track preference
  * Rearrange settings window for 720p
  * Save/restore maximized/minimized state
  * Implement additive speed step
  * Correctly set video filters
  * Add ability to save thumbnails
  * Implement after playback -> play next
  * Implement thinner time fields like mpc-hc
  * Implement limiting volume to 100%% like mpc-hc
  * Audio output settings now on own page
  * Add logging framework
  Notes:
  * In addition, there may be other improvements not listed here.
  * As the playlist format has changed, opening the saved data
    of this version with older versions may result in data loss.
- Switch to stable version and remove _service
* Fri Jul  3 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 18.08+git20200704
- Switch again to the original developer's repository
- Add _service
- Drop mpv-qthelper.patch (merged upstream)
* Thu Mar 19 2020 Luigi Baldoni <aloisio@gmx.com>
- Added mpv-qthelper.patch
- Dropped group tag
* Sat Jun 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 18.08+git20190618
  * Unofficial release, all of the available updates before
    the upstream repository was deleted
* Sat Aug  4 2018 aloisio@gmx.com
- Update to version 18.08
  * Saner defaults (volume/zoom/tracks)
  * Add a device manager to implement the Open Disc menu
  * Add subtitles toggle button (#167 #211)
  * Improve usage of the fallback icon theme (#208)
  * Add shortcut to escape fullscreen (#194)
  * Add Spanish translation (#206)
  * Sanitise MPRIS metadata (#203 #204)
  * Implement deltaExtraPlaytimes IPC command (#200)
  * Implement early multi-process (#176)
  * Support Qt 5.11 (#198)
  * Extract tagged version information during the build process
  * Improve the playlist's context menu
  * Implement shuffle mode (#190)
  * Use mpv's new hook API (#189)
  * Fix regression with capitalized file extensions (#186)
  * Fix banding on Wayland (#164)
  * Add high bit-depth screenshotting option (#183)
  * Load mpv Lua scripts at [configfolder]/scripts (#182)
  * Wire up the autoload subs fields
  * Add --freestanding window launch option (#176)
  * Add option to suppress OSD messages (#179)
  * Only accept mouse events over the video widget (#177)
  * Allow the speed step to be customized (#175)
  * Don't add external subfiles to the playlist (#174)
  * Use mpv's internal stats plugin
  * Implement moving to next/previous file in the folder
  * Use mpv's new render API
  * In addition, there may be other changes not listed here.
  * Notes
    + This version is incompatible with older mpv releases. mpv
    0.29.0 requires ffmpeg 4.0
    + The optional device manager functionality requires the
    presence of the udisks2 dbus service. 26e8c19
    + Running mpc-qt with some of the circulating mpv lua
    scripts may void your warranty.
- Dropped mpc-qt-Qt511.patch (merged upstream)
* Mon Jun 11 2018 aloisio@gmx.com
- Added mpc-qt-Qt511.patch to fix build with Qt 5.11
* Sun Mar 11 2018 aloisio@gmx.com
- Update to version 18.03
  * (Re)enable building with older Qt versions (#136)
  * Update mpc-qt.desktop (#165)
  * Fix crash with svp (#140)
  * Bitblit the time and volume sliders (#147)
  * Add custom seek duration (#156)
  * Add Russian translation (#151)
  * Add checkboxes next to the zoom levels (#146)
* Wed Nov  1 2017 aloisio@gmx.com
- Update to version 17.11
  * Remember time of favorites
  * Remember correct config folder (#137)
  * Correct window frame calculation (#138)
  * Don't crash in a new ipc connection (#140)
- Dropped Qt-5.6-backport_setFlag.patch (merged upstream)
* Sun Oct  1 2017 aloisio@gmx.com
- Update to version 17.10
  * Implement favorites menu (use mouse for moving and renaming)
  * Implement mpris protocol (Linux only)
  * Improve .desktop file (Linux only)
  * Fix cli --size implementation (#89)
  * Fix save image filename extension (#127)
  * Use expected window placement on first run (#128)
- Use upstream .desktop file
- Fixed creation date and time
- Added Qt-5.6-backport_setFlag.patch
* Fri Sep  1 2017 aloisio@gmx.com
- Fixed locale path
* Fri Sep  1 2017 aloisio@gmx.com
- Update to version 17.09
  * Export MediaInfo to text file (#119)
  * USe correct mousewheel direction (#118)
  * Premangle the temporary image filename (#120)
  * Don't reset the play speed when pressing play (#117)
  * Honor --size argument (#89)
  * Add palette editor (some shades are drawn by the system on
    Windows)
  * Custom icons and basic themeing (#65)
  * Integration of argon's stats.lua (#104)
  * Populate audio device lists with mpv 0.26.0 (mentioned in #116)
  * Add right-click menu (#113)
  * Simplified resizing code (#114)
* Sun Aug 13 2017 aloisio@gmx.com
- Update to release 17.08
* Sun Jul  2 2017 aloisio@gmx.com
- Update to stable version 17.07
* Tue Jun  6 2017 olaf@aepfle.de
- Adjust usage of gccN-c++ for Leap42 and SLE12
* Wed May 31 2017 aloisio@gmx.com
- Change format for build date
- Add locale file
* Wed Mar  8 2017 aloisio@gmx.com
- Force gcc5 for Leap targets
* Wed Mar  8 2017 opensuse-packaging@opensuse.org
- Update to version 0~git20170308.548cd70:
  * Switch Unix/X11 to Linux behavior for consistency
  * mpvwidget: use undeprecated property names
  * readme: bump required mpv version to 0.24.0
  * remove outdated link
  * openfiledialog: add to project
  * [many]: implement open file dialog
  * readme: fix link to mpc-hc
  * settingswindow: implement video presets
  * settingswindow: remove reference to prescalers
  * qdrawnslider,qdrawnstatus: use QWidget as base class
* Fri Nov 18 2016 aloisio@gmx.com
- Initial package
